@@ -34,4 +34,7 @@ _ = lambda dict_arg, **kwargs: _ANYARGS(kwargs, **dict_arg)
 _ = lambda *args: _ANYARGS()
 _ = lambda *args: _ANYARGS(*list([3, 4]))
 _ = lambda *args: _ANYARGS(*[3, 4])
-_ = lambda list_arg, *args: _ANYARGS(args, *list_arg)
\ No newline at end of file
+_ = lambda list_arg, *args: _ANYARGS(args, *list_arg)
+_ = lambda: _ANYARGS(*[3])
+_ = lambda: _ANYARGS(**{'three': 3})
+_ = lambda: _ANYARGS(*[3], **{'three': 3})
